# Pypeul

Pypeul is an IRC client library written in Python.

It mainly aims at creating IRC bots and provides an easy to use API
based on callbacks. It also features a nice way to parse and write
formatted text.

**Copyright**: Copyright 2010-2012- by the Pypeul team, see AUTHORS.

**License**: LGPL, see COPYING for details.
